[Libreoffice-commits] core.git: xmlsecurity/source

Libreoffice Gerrit user logerrit at kemper.freedesktop.org
Sun Dec 30 08:10:53 UTC 2018


 xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx |   10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

New commits:
commit 8e5844ad2321ae58762e74681baf2895190fa3e3
Author:     Andrea Gelmini <andrea.gelmini at gelma.net>
AuthorDate: Wed Dec 26 13:56:05 2018 +0100
Commit:     Julien Nabet <serval2412 at yahoo.fr>
CommitDate: Sun Dec 30 09:10:32 2018 +0100

    Fix typo in code
    
    Change-Id: I671749843ee14b18c4786a132ca9c6ad30efc625
    Reviewed-on: https://gerrit.libreoffice.org/65732
    Tested-by: Jenkins
    Reviewed-by: Julien Nabet <serval2412 at yahoo.fr>

diff --git a/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx b/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
index b0d0835e8a81..de0cd43f3c8f 100644
--- a/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
+++ b/xmlsecurity/source/xmlsec/xmldocumentwrapper_xmlsecimpl.cxx
@@ -51,7 +51,7 @@ namespace cssxw = com::sun::star::xml::wrapper;
 /* used by the recursiveDelete method */
 #define NODE_REMOVED    0
 #define NODE_NOTREMOVED 1
-#define NODE_STOPED     2
+#define NODE_STOPPED     2
 
 XMLDocumentWrapper_XmlSecImpl::XMLDocumentWrapper_XmlSecImpl()
     : m_nCurrentPosition(0)
@@ -421,7 +421,7 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
  *   RESULT
  *  result -    the result of the deletion process, can be one of following
  *          values:
  *          NODE_STOPED - the process is interrupted by meeting the
  *              m_pStopAtNode
  *          NODE_NOTREMOVED - the pNode is not completely removed
  *              because there is its descendant in the
@@ -436,7 +436,7 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
 {
     if (pNode == m_pStopAtNode)
     {
-        return NODE_STOPED;
+        return NODE_STOPPED;
     }
 
     if (pNode != m_pCurrentReservedNode)
@@ -454,8 +454,8 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
 
             switch (nResult)
             {
-            case NODE_STOPED:
-                return NODE_STOPED;
+            case NODE_STOPPED:
+                return NODE_STOPPED;
             case NODE_NOTREMOVED:
                 bIsRemoved = false;
                 break;
@@ -421,7 +421,7 @@ sal_Int32 XMLDocumentWrapper_XmlSecImpl::recursiveDelete(
  *  result -    the result of the deletion process, can be one of following
  *          values:
- *          NODE_STOPED - the process is interrupted by meeting the
+ *          NODE_STOPPED - the process is interrupted by meeting the
  *              m_pStopAtNode
  *          NODE_NOTREMOVED - the pNode is not completely removed


More information about the Libreoffice-commits mailing list